<?php
// "Awards" handling functions
if (!defined ("AWARDS"))
{
 define ("AWARDS","(c)");

 include_once ("../SYSTEM/CONSTS.PHP");
 include_once ("../SYSTEM/MISC.PHP");
 include_once ("../SYSTEM/DB_FUNCS.PHP");
 include_once ("../SYSTEM/SESSIONS.PHP");

 class TAward
 {
  var $a_index;
  var $author_id;
  var $author_nick;
  var $ip;
  var $expiry;
  var $type;
  var $channel_id;
  var $issuer_id;
  var $issuer_nick;
  var $supermod;
  var $comment;
 };
 
 class TAwardCount
 {
  var $warnings;
  var $rdonlys;
  var $bans;
 };

 // awd_get_awards_author_id ($aid,$channel_id,$type,$ip,$rems=0)
 // Gets all "awards" received by given author ID (or at given ip)
 // Pars: author id, channel id (-1 if for all), award type (-1 if any type),
 //  ip ("-" if not required IP comparison), rems (if true, comments are
 //  also selected).
 // Returns: array of TAward's
 function awd_get_awards_author_id ($aid,$channel_id,$type,$ip,$rems=0)
 {
  $rez=array ();
  if (dbf_select_query ("SELECT
  author_id,
  author_nick,
  ip,
  expiry,
  type,
  channel_id,
  issuer_id,
  supermod,
  nick".($rems? ",comment " : " ")."
  FROM awards,users
  WHERE
  (
  (author_id='".$aid."')". // if ip='-' "(aid=aid)", else "(aid=aid) or (ip=ip)"
  (" or (ip='".$ip."')").
  ")
   and
  (issuer_id=u_index) and ".
  // ((channel_id=".$channel_id.") or (channel_id=-1) or (".$channel_id."=-1)) and
  ($channel_id==-1? "" : "((channel_id=".$channel_id.") or (channel_id=-1)) and")
  ."((type=".$type.") or (".$type."=-1)) ORDER BY expiry DESC;")>=0)
  {
   for ($i=0;;$i++)
   {
    $row=dbf_fetch_row ();
    if (!$row) break;
    $rez[$i]=new TAward;
    $rez[$i]->author_id=$row['author_id'];
    $rez[$i]->author_nick=$row['author_nick'];
    $rez[$i]->ip=$row['ip'];
    $rez[$i]->expiry=$row['expiry'];
    $rez[$i]->type=$row['type'];
    $rez[$i]->channel_id=$row['channel_id'];
    $rez[$i]->issuer_id=$row['issuer_id'];
    $rez[$i]->issuer_nick=$row['nick'];
    $rez[$i]->supermod=$row['supermod'];
    $rez[$i]->comment=$row['comment'];
   }
   dbf_free_result ();
  }
  else return FALSE;
  return $rez;
 }
 
 // awd_count_awards ($aid,$channel_id,$ip)
 // Counts awards of diff types received by given user (author id or IP)
 // Pars: author id, channel_id, IP
 // Returns: TAwardCount (on success) or FALSE (on error)
 function awd_count_awards ($aid,$channel_id,$ip)
 {
  $awds=awd_get_awards_author_id ($aid,$channel_id,-1,$ip);
  if (!misc_test_arr ($awds)) return FALSE;
  $rez=new TAwardCount;
  $rez->warnings=0;
  $rez->rdonlys=0;
  $rez->bans=0;
  foreach ($awds as $awd)
  {
   switch ($awd->type)
   {
    case (BZ_AWD_WARNING):
     $rez->warnings++; break;
    case (BZ_AWD_RDONLY):
     $rez->rdonlys++; break;
    case (BZ_AWD_BAN):
     $rez->bans++; break;
   }
  }
  return $rez;
 }

 // awd_get_awards_channel ($channel_id)
 // Gets all awards for a given channel
 // Pars: channel id (-1 if global only, otherwise - not globals), issuer's moder status (-1 if any)
 function awd_get_awards_channel ($channel_id)
 {
  $rez=array ();
  if (dbf_select_query ("SELECT DISTINCTROW
  a_index,
  author_id,
  author_nick,
  ip,
  expiry,
  `type`,
  channel_id,
  issuer_id,
  supermod,
  nick,
  `comment`
  FROM awards,users
  WHERE
  (issuer_id=u_index) and
  ((channel_id=".$channel_id.") or (channel_id=-1)) ORDER BY a_index ASC;")>=0)
  {
   for ($i=0;;$i++)
   {
    $row=dbf_fetch_row ();
     if (!$row) break;
    $rez[$i]=new TAward;
    $rez[$i]->a_index=$row['a_index'];
    $rez[$i]->author_id=$row['author_id'];
    $rez[$i]->author_nick=$row['author_nick'];
    $rez[$i]->ip=$row['ip'];
    $rez[$i]->expiry=$row['expiry'];
    $rez[$i]->type=$row['type'];
    $rez[$i]->channel_id=$row['channel_id'];
    $rez[$i]->issuer_id=$row['issuer_id'];
    $rez[$i]->issuer_nick=$row['nick'];
    $rez[$i]->supermod=$row['supermod'];
    $rez[$i]->comment=$row['comment'];
   }
   dbf_free_result ();
  }
  else return FALSE;
  return $rez;
 }

 // awd_add_award ($award)
 // Adds an "award" for given author
 // Pars: TAward ($expiry set to duration in seconds,$issuer_nick is ignored)
 // Returns: TRUE (ok)/FALSE (not ok)
 function awd_add_award ($award)
 {
  return dbf_query ("INSERT INTO awards
  (author_id,author_nick,expiry,type,channel_id,issuer_id,supermod,comment,ip)
  VALUES (
  '".$award->author_id."',
  '".$award->author_nick."',
  UNIX_TIMESTAMP(NOW())+".$award->expiry.",
  $award->type,
  $award->channel_id,
  $award->issuer_id,
  $award->supermod,
  '".$award->comment."',
  '".$award->ip."'
  );");
 }
 
 // awd_remove_award ($aid,$smod)
 // Deletes given award
 // Pars: award id, super moder status (0/1)
 // Returns: TRUE (ok)/FALSE (not ok)
 function awd_remove_award ($aid,$smod)
 {
  return dbf_query ("DELETE FROM awards WHERE
  (a_index=".$aid.") and (supermod<=".$smod.");");
 }
 
 // awd_drop_expired_awards ()
 // Removes expired awards
 // Pars: none
 // Return: TRUE (success)/FALSE (not success)
 // Remarks: Yet always succeeds. Should be called as frequently as possible.
 function awd_drop_expired_awards ()
 {
  return dbf_query ("DELETE FROM awards WHERE
  (UNIX_TIMESTAMP(NOW())>expiry) and
  (type<>".BZ_AWD_BAN.");");
 }
}
?>