<?php

// Operations with channels
// dbf connection must be established before calling these funcs!

if (!defined ("CHANNELS"))
{
 define ("CHANNELS","(c)");
 include_once ("../SYSTEM/CONSTS.PHP");
 include_once ("../SYSTEM/DB_FUNCS.PHP");

 class TChannel
 {
  var $c_index;
  var $owner;
  var $name;
  var $policy;
 };

 class TAuthor
 {
  var $author_id;
  var $ip;
  var $nick;
  var $color;
 };

 // chan_get_channel ($channel_id,$pure_name=FALSE)
 // Get info of channel
 // Pars: channel_id, pure_name (TRUE if not needed prefixing private channels names)
 // Returns: TChannel or FALSE (if not success)
 function chan_get_channel ($channel_id,$pure_name=FALSE)
 {
  if (dbf_select_query ("SELECT
   c_index,
   owner,
   name,
   policy
   FROM channels WHERE c_index=$channel_id;")<1) return FALSE;
  $rez=new TChannel;
  $row=dbf_fetch_row ();
  dbf_free_result ();
  $rez->c_index=$row['c_index'];
  $rez->owner=$row['owner'];
  $rez->name=$row['name'];
  $rez->policy=$row['policy'];
  if ($rez->owner!=-1)
  {
   if (dbf_select_query ("SELECT nick FROM users WHERE u_index=$rez->owner;")<1)
    return FALSE;
   $row=dbf_fetch_row ();
   dbf_free_result ();
   $rez->name=$pure_name? $rez->name : ("[".$row['nick']."] ".$rez->name);
  }
  return $rez;
 }

 // chan_get_rules ($channel_id)
 // Get text of rules for given channel id
 // Pars: channel id
 // Returns: string (empty if no rules, error text if error occurs)
 function chan_get_rules ($channel_id)
 {
  if (dbf_select_query ("SELECT rules FROM channels WHERE c_index=$channel_id")>0)
  {
   $row=dbf_fetch_row ();
   return $row['rules'];
  }
  return BZ_ERR_DATABASE_CONNECTION;
 }

 // chan_get_channels ()
 // Gets all channels (except those having "NO ACCESS" policy)
 // Pars: none
 // Returns: array of TChannel or false
 function chan_get_channels ()
 {
  if (dbf_select_query ("SELECT
   c_index,
   owner,
   name,
   policy
   FROM channels WHERE (owner=-1) and (policy<>".BZ_CP_NOACCESS.")
   ORDER BY name ASC;")<0) return FALSE;
  $rez=array ();
  for ($i=0;;$i++)
  {
   $row=dbf_fetch_row ();
   if (!$row) break;
   $rez[$i]=new TChannel;
   $rez[$i]->c_index=$row['c_index'];
   $rez[$i]->owner=$row['owner'];
   $rez[$i]->name=$row['name'];
   $rez[$i]->policy=$row['policy'];
  }
  // Owned channels - after common
  if (dbf_select_query ("SELECT
   c_index,
   owner,
   name,
   nick,
   policy
   FROM channels,users WHERE
   (owner<>-1) and
   (policy<>".BZ_CP_NOACCESS.") and
   (owner=u_index)
   ORDER BY name ASC;")<0) return FALSE;
  for (;;$i++)
  {
   $row=dbf_fetch_row ();
   if (!$row) break;
   $rez[$i]=new TChannel;
   $rez[$i]->c_index=$row['c_index'];
   $rez[$i]->owner=$row['owner'];
   $rez[$i]->name="[".$row['nick']."] ".$row['name'];
   $rez[$i]->policy=$row['policy'];
  }
  return $rez;
 }
 
 // chan_get_all_channels ()
 // Gets all channels. Really ALL channels.
 // Pars: none
 // Returns: array of TChannel or false
 function chan_get_all_channels ()
 {
  if (dbf_select_query ("SELECT
   c_index,
   owner,
   name,
   policy
   FROM channels WHERE (owner=-1)
   ORDER BY c_index ASC;")<0) return FALSE;
  $rez=array ();
  for ($i=0;;$i++)
  {
   $row=dbf_fetch_row ();
   if (!$row) break;
   $rez[$i]=new TChannel;
   $rez[$i]->c_index=$row['c_index'];
   $rez[$i]->owner=$row['owner'];
   $rez[$i]->name=$row['name'];
   $rez[$i]->policy=$row['policy'];
  }
  // Owned channels - after common
  if (dbf_select_query ("SELECT
   c_index,
   owner,
   name,
   nick,
   policy
   FROM channels,users WHERE
   (owner<>-1) and
   (owner=u_index)
   ORDER BY c_index ASC;")<0) return FALSE;
  for (;;$i++)
  {
   $row=dbf_fetch_row ();
   if (!$row) break;
   $rez[$i]=new TChannel;
   $rez[$i]->c_index=$row['c_index'];
   $rez[$i]->owner=$row['owner'];
   $rez[$i]->name="[".$row['nick']."] ".$row['name'];
   $rez[$i]->policy=$row['policy'];
  }
  dbf_free_result ();
  return $rez;
 }
 
 // chan_get_channel_authors ($channel_id)
 // Gets all participants that posted messages to given channel
 // Pars: channel id
 // Return: array of TAuthor's or FALSE (on error)
 function chan_get_channel_authors ($channel_id)
 {
  $rez=array ();
  if (dbf_select_query ("SELECT DISTINCT
  nick,author_id,ip,color FROM messages WHERE
  ((channel_id=$channel_id) and (author_id<>'sys'))
  GROUP BY `time` ORDER BY `time` DESC;")<0)
   return FALSE;
  for ($i=0;;$i++)
  {
   $row=dbf_fetch_row ();
   if (!$row) break;
   $rez[$i]=new TAuthor;
   $rez[$i]->author_id=$row['author_id'];
   $rez[$i]->ip=$row['ip'];
   $rez[$i]->nick=$row['nick'];
   $rez[$i]->color=$row['color'];
  }
  dbf_free_result ();
  return $rez;
 }
 
 // chan_add_channel ($owner_uid,$policy)
 // Adds a channel for specified owner
 // Pars: owner id (-1 (public) not allowed), policy code
 // Returns: channel id (or -1 on failure)
 function chan_add_channel ($owner_uid,$policy)
 {
  // test if channel exists
  $rez=dbf_select_query
   ("SELECT c_index FROM channels WHERE owner=$owner_uid;");  
  if (!$rez)
  {
   dbf_free_result ();
   dbf_query
    ("INSERT INTO channels (owner,policy) VALUES ($owner_uid,$policy);");
   $rez=dbf_select_query
    ("SELECT c_index FROM channels WHERE owner=$owner_uid;");
  }
  if ($rez<1)
  {
   dbf_free_result ();
   return -1;
  }
  $row=dbf_fetch_row ();
  dbf_free_result ();
  return $row['c_index'];
 }

 // chan_add_public_channel ($name)
 // Adds a public channel with specified name. Policy is set to NA, rules to empty string
 // Pars: channel name, policy code
 // Returns: TRUE (success)/FALSE (not success)
 function chan_add_public_channel ($name)
 {
  return dbf_query
   ("INSERT INTO channels (owner,name,policy)
    VALUES (-1,'".$name."',".BZ_CP_NOACCESS.");");
 }
 
 // chan_edit_channel ($channel,$new_rules)
 // Modifies channel's parameters (policy, rules)
 // Pars: TChannel (channel_id specifies channel), text for new rules
 // ReturnS: TRUE (ok)/FALSE (not ok)
 function chan_edit_channel ($channel,$new_rules)
 {
  return
  dbf_query ("UPDATE channels SET
  name='".$channel->name."',
  policy=".$channel->policy.",
  rules='".$new_rules."'
  WHERE c_index=".$channel->c_index.";");
 }
 
 // chan_edit_channel_name ($channel_id,$new_name)
 // Modifies given channel's name
 // Pars: channel id, new name
 // Returns: TRUE (success)/FALSE (not success)
 function chan_edit_channel_name ($channel_id,$new_name)
 {
  return
  dbf_query ("UPDATE channels SET
  name='".$new_name."' WHERE c_index=$channel_id;");
 }
 
 // chan_edit_channel_rules ($channel_id,$new_rules)
 // Modifies given channel's rules
 // Pars: channel id, new rules
 // Returns: TRUE (success)/FALSE (not success)
 function chan_edit_channel_rules ($channel_id,$new_rules)
 {
  return
  dbf_query ("UPDATE channels SET
  rules='".$new_rules."' WHERE c_index=$channel_id;");
 }

 // chan_edit_channel_policy ($channel_id,$new_policy)
 // Modifies given channel's rules
 // Pars: channel id, new rules
 // Returns: TRUE (success)/FALSE (not success)
 function chan_edit_channel_policy ($channel_id,$new_policy)
 {
  return
  dbf_query ("UPDATE channels SET
  policy=$new_policy WHERE c_index=$channel_id;");
 }
 
 // chan_remove_channel ($channel_id)
 // Removes channel and all things related to it
 // Pars: channel id
 // Returns: TRUE (success)/FALSE (not success)
 function chan_remove_channel ($channel_id)
 {
  return
  dbf_query ("DELETE FROM sessions WHERE channel_id=$channel_id;") and
  dbf_query ("DELETE FROM messages WHERE channel_id=$channel_id;") and
  dbf_query ("DELETE FROM user_stat WHERE channel_id=$channel_id;") and
  dbf_query ("DELETE FROM awards WHERE channel_id=$channel_id;") and
  dbf_query ("DELETE FROM channels WHERE c_index=$channel_id;");
 }
 
 // chan_clear_channel ($channel_id)
 // Clear channel of messages (all users that are in channel will be logged off by force :)
 // Pars: channel id
 // Returns: TRUE (success)/FALSE (not success)
 function chan_clear_channel ($channel_id)
 {
  return
  dbf_query ("DELETE FROM sessions WHERE channel_id=$channel_id;") and
  dbf_query ("DELETE FROM messages WHERE channel_id=$channel_id;");
 }
}
?>